@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -75,7 +75,7 @@ def template_resolve(template):
 
     # retrieves both the complete locale set under the current request and
     # the language base value for the same locale (to be used as fallback)
-    locale = flask.request.locale if hasattr(flask.request, "locale") else None
+    locale = flask.request.locale if hasattr(flask.request, "locale") else None  #@UndefinedVariable
     language = locale.split("_", 1)[0] if locale else None
 
     # sets the fallback name as the "original" template path, because
