@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -681,6 +681,32 @@ class UtilTest(quorum.TestCase):
             lambda: quorum.verify_not_equal(1, 1, exception = quorum.OperationalError)
         )
 
+    @quorum.secured
+    def test_verify_type(self):
+        result = quorum.verify_type("hello", str)
+        self.assertEqual(result, None)
+
+        result = quorum.verify_type(1, int)
+        self.assertEqual(result, None)
+
+        result = quorum.verify_type(None, int)
+        self.assertEqual(result, None)
+
+        self.assertRaises(quorum.AssertionError, lambda: quorum.verify_type(1, str))
+
+        self.assertRaises(
+            quorum.OperationalError,
+            lambda: quorum.verify_type(1, str, exception = quorum.OperationalError)
+        )
+
+        self.assertRaises(quorum.AssertionError, lambda: quorum.verify_type(None, str, null = False))
+
+        self.assertRaises(
+            quorum.OperationalError,
+            lambda: quorum.verify_type(None, str, null = False, exception = quorum.OperationalError)
+        )
+
+    @quorum.secured
     def test_verify_many(self):
         result = quorum.verify_many((1 == 1, 2 == 2, 3 == 3))
         self.assertEqual(result, None)
